# Generated by Django 5.0.7 on 2024-07-30 20:00

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_service", "0003_installedapp_created_at_installedapp_status_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="AppPermission",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255)),
                ("codename", models.CharField(max_length=100)),
                (
                    "installed_app",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="permissions",
                        to="artd_service.installedapp",
                    ),
                ),
            ],
            options={
                "verbose_name": "App Permission",
                "verbose_name_plural": "App Permissions",
            },
        ),
    ]
