# Generated by Django 5.0.7 on 2024-07-30 19:43

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_service", "0002_installedapp"),
    ]

    operations = [
        migrations.AddField(
            model_name="installedapp",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True,
                default=datetime.datetime(
                    2024, 7, 30, 19, 43, 31, 401740, tzinfo=datetime.timezone.utc
                ),
                help_text="Date and time on which the object was created",
                verbose_name="Created at",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="installedapp",
            name="status",
            field=models.BooleanField(
                default=True, help_text="Status of the object", verbose_name="Status"
            ),
        ),
        migrations.AddField(
            model_name="installedapp",
            name="updated_at",
            field=models.DateTimeField(
                auto_now=True,
                help_text="Date and time on which the object was updated",
                verbose_name="Updated at",
            ),
        ),
    ]
