# Generated by Django 5.0.8 on 2024-08-06 21:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('artd_service', '0006_serviceapps'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='serviceapps',
            options={'verbose_name': 'Service Apps', 'verbose_name_plural': 'Service Apps'},
        ),
    ]
