# Generated by Django 5.0.7 on 2024-07-30 19:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_service", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="InstalledApp",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        help_text="InstalledApp",
                        max_length=255,
                        verbose_name="Installed App",
                    ),
                ),
            ],
            options={
                "verbose_name": "InstalledApp",
                "verbose_name_plural": "Installed Apps",
            },
        ),
    ]
